@@ -61,19 +61,19 @@
 
 /* Type unsigned long has sizeof = 4 and alignment = 4. */
 
-/* Type long long has sizeof = 8 and alignment = 8. */
+/* Type long long has sizeof = 8 and alignment = 4. */
 #define sizeof_long_long 8
-#define alignment_long_long 8
+#define alignment_long_long 4
 
-/* Type unsigned long long has sizeof = 8 and alignment = 8. */
+/* Type unsigned long long has sizeof = 8 and alignment = 4. */
 
 /* Type float has sizeof = 4 and alignment = 4. */
 #define sizeof_float 4
 #define alignment_float 4
 
-/* Type double has sizeof = 8 and alignment = 8. */
+/* Type double has sizeof = 8 and alignment = 4. */
 #define sizeof_double 8
-#define alignment_double 8
+#define alignment_double 4
 
 /* Type char * has sizeof = 4 and alignment = 4. */
 
@@ -81,14 +81,14 @@
 
 /* Type function * has sizeof = 4 and alignment = 4. */
 
-/* Type unsigned short is stored BIG-ENDIAN in memory (i.e. like mc68000 or sparc). */
-#define short_big_endian
-/* Type unsigned int is stored BIG-ENDIAN in memory (i.e. like mc68000 or sparc). */
-#define int_big_endian
-/* Type unsigned long is stored BIG-ENDIAN in memory (i.e. like mc68000 or sparc). */
-#define long_big_endian
-/* Type unsigned long long is stored BIG-ENDIAN in memory (i.e. like mc68000 or sparc). */
-#define long_long_big_endian
+/* Type unsigned short is stored LITTLE-ENDIAN in memory (i.e. like Z80 or VAX). */
+#define short_little_endian
+/* Type unsigned int is stored LITTLE-ENDIAN in memory (i.e. like Z80 or VAX). */
+#define int_little_endian
+/* Type unsigned long is stored LITTLE-ENDIAN in memory (i.e. like Z80 or VAX). */
+#define long_little_endian
+/* Type unsigned long long is stored LITTLE-ENDIAN in memory (i.e. like Z80 or VAX). */
+#define long_long_little_endian
 
-/* Stack grows down, ca. 112 bytes per function call. */
+/* Stack grows down, ca. 20 bytes per function call. */
 #define stack_grows_down
